diff graal/GraalCompiler/src/com/sun/c1x/ir/BlockBegin.java @ 2582:768d77a1c7af

new node layout: Instruction
author Lukas Stadler <lukas.stadler@jku.at>
date Thu, 05 May 2011 13:47:14 +0200
parents 4a36a0bd6d18
children 0c6564c254af
line wrap: on
line diff
--- a/graal/GraalCompiler/src/com/sun/c1x/ir/BlockBegin.java	Thu May 05 13:27:48 2011 +0200
+++ b/graal/GraalCompiler/src/com/sun/c1x/ir/BlockBegin.java	Thu May 05 13:47:14 2011 +0200
@@ -842,7 +842,7 @@
 
     /**
      * Formats a given instruction as a value in a {@linkplain FrameState frame state}. If the instruction is a phi defined at a given
      * block, its {@linkplain Phi#inputCount() inputs} are appended to the returned string.
      *
      * @param index the index of the value in the frame state
      * @param value the frame state value
@@ -858,7 +858,7 @@
             // print phi operands
             if (phi.block() == this) {
                 sb.append(" [");
-                for (int j = 0; j < phi.inputCount(); j++) {
+                for (int j = 0; j < phi.phiInputCount(); j++) {
                     sb.append(' ');
                     Value operand = phi.inputAt(j);
                     if (operand != null) {
@@ -842,7 +842,7 @@
     /**
      * Formats a given instruction as a value in a {@linkplain FrameState frame state}. If the instruction is a phi defined at a given
-     * block, its {@linkplain Phi#inputCount() inputs} are appended to the returned string.
+     * block, its {@linkplain Phi#phiInputCount() inputs} are appended to the returned string.
      *
      * @param index the index of the value in the frame state